==> pyloobins-0.1.6.tar.gz: pyloobins-0.1.6/src/pyloobins/cli.py <==
"""Model for CLI functions"""
import os
import sys

import click

from .util import get_loobins, make_template, normalize_file_name, validate_loobin


@click.group()
def cli():
    """Create, validate, and view LOOBin objects."""


@cli.command()
@click.option(
    "--file",
    type=str,
    required=True,
    help="File location of the LOOBin YAML file to validate.",
)
def validate(file: str) -> None:
    """Validate a LOOBin YAML file."""
    if validate_loobin(yml_path=file):
        print(f"LOOBin at {file} is valid.")
        sys.exit(0)
    else:
        print(f"LOOBin at {file} is NOT valid.")
        sys.exit(1)


@cli.command()
@click.option("--name", type=str, required=False, help="Enter the name of the binary")
@click.option(
    "--path",
    type=str,
    required=False,
    help="Enter the path where you would like to create the template YAML file.",
)
def create(name: str, path: str) -> None:
    """Create a YAML template file for a new LOOBin."""
    template = make_template(name=name).to_yaml()
    file_name = normalize_file_name(name) if name else "template"
    file_path = path if path and os.path.exists(path) else "./"
    if not os.path.exists(file_path):
        click.echo(
            f"The specified path did not exist. "
            f"Creating the {file_name}.yml file in the current directory."
        )
    with open(
        file=f"{file_path}{file_name}.yml", mode="w", encoding="utf-8"
    ) as out_file:
        out_file.write(template)
        out_file.close()


@cli.command()
@click.option("--name", type=str, required=True, help="Enter the name of the binary")
@click.option(
    "--path",
    type=str,
    required=False,
    help="Enter the path where you would like to create the template YAML file.",
)
def get(name: str, path: str = "") -> None:
    """Get a LOOBin object."""
    if path:
        loobins = get_loobins(path=path)
    else:
        loobins = get_loobins()

    res = [loobin for loobin in loobins if loobin.name == name]

    if len(res) == 0:
        print(f"No LOOBin found for {name}.")
    else:
        print(res[0].json(indent=True, exclude_none=True))


if __name__ == "__main__":
    sys.exit(cli())

==> pyloobins-0.1.7.tar.gz: pyloobins-0.1.7/src/pyloobins/cli.py <==
"""Model for CLI functions"""
import os
import sys

import click

from .util import get_loobins, make_template, normalize_file_name, validate_loobin


@click.group()
def cli():
    """Create, validate, and view LOOBin objects."""


@cli.command()
@click.option(
    "--path",
    type=str,
    required=True,
    help="The path of the LOOBin YAML file to validate.",
)
def validate(file: str) -> None:
    """Validate a LOOBin YAML file."""
    if validate_loobin(yml_path=file):
        print(f"LOOBin at {file} is valid.")
        sys.exit(0)
    else:
        print(f"LOOBin at {file} is NOT valid.")
        sys.exit(1)


@cli.command()
@click.option("--name", type=str, required=False, help="Enter the name of the binary")
@click.option(
    "--path",
    type=str,
    required=False,
    help="Enter the path where you would like to create the template YAML file.",
)
def create(name: str, path: str) -> None:
    """Create a YAML template file for a new LOOBin."""
    template = make_template(name=name).to_yaml()
    file_name = normalize_file_name(name) if name else "template"
    file_path = path if path and os.path.exists(path) else "./"
    if not os.path.exists(file_path):
        click.echo(
            f"The specified path did not exist. "
            f"Creating the {file_name}.yml file in the current directory."
        )
    with open(
        file=f"{file_path}{file_name}.yml", mode="w", encoding="utf-8"
    ) as out_file:
        out_file.write(template)
        out_file.close()


@cli.command()
@click.option("--name", type=str, required=True, help="Enter the name of the binary")
@click.option(
    "--path",
    type=str,
    required=False,
    help="Enter the path where you would like to create the template YAML file.",
)
def get(name: str, path: str = "") -> None:
    """Get a LOOBin object."""
    if path:
        loobins = get_loobins(path=path)
    else:
        loobins = get_loobins()

    res = [loobin for loobin in loobins if loobin.name == name]

    if len(res) == 0:
        print(f"No LOOBin found for {name}.")
    else:
        print(res[0].json(indent=True, exclude_none=True))


if __name__ == "__main__":
    sys.exit(cli())
